@@ -1,5 +1,5 @@
 if (requireNamespace("tinytest", quietly=TRUE)) {
-  if (length(unclass(packageVersion("ncvreg"))[[1]]) == 4 | Sys.getenv('R_FORCE_TEST') == 'TRUE') {
+  if (identical(tolower(Sys.getenv("R_FORCE_TEST")), "true")) {
     tinytest::test_package("ncvreg", pattern="^[^_].*\\.[rR]$")
   }
 }
